@@ -46,6 +46,11 @@ separator() {
     echo "==============================================="
 }
 
+# Print message on standard error
+warn() {
+    echo "$*" >&2
+}
+
 # Execute a command inside chroot
 # Signature: exec_chroot <chroot path> <command ...>
 exec_chroot() {
@@ -87,13 +92,14 @@ create_user() {
         "${user}" || exit 1
 }
 
-# Setup root user settings (password, etc)
-# Signature: setup_root_user <chroot> <root pass>
-setup_root_user() {
+# Setup user's password in chroot
+# Signature: set_user_password <chroot> <login> <password>
+set_user_password() {
     local _chroot="${1}"
-    local root_pass="${2}"
-    echo "root:${root_pass}" | exec_chroot "${_chroot}" chpasswd \
-        || return ${?}
+    local login="${2}"
+    local password="${3}"
+    # TODO: some validation
+    echo "${login}:${password}" | exec_chroot "${_chroot}" chpasswd
 }
 
 # Delete live image user from chroot if exists
@@ -162,7 +168,8 @@ setup_users() {
     create_user "${_chroot}" "${user}" || return ${?}
 
     # setup passwords
-    setup_root_user "${_chroot}" "${root_pass}" || return ${?}
+    set_user_password "${_chroot}" "${user}" "${user_pass}" || return ${?}
+    set_user_password "${_chroot}" "root" "${root_pass}" || return ${?}
 }
 
 # Setup language
@@ -627,12 +634,12 @@ setup_entropy() {
 main() {
 
     if [ "$(whoami)" != "root" ]; then
-        echo "Y U NO root" >&2
+        warn "Y U NO root"
         return 1
     fi
     if [ ${#} -lt 1 ]; then
-        echo "Y U NO correct args" >&2
-        echo "${0} <chroot path>" >&2
+        warn "Y U NO correct args"
+        warn "${0} <chroot path>"
         return 1
     fi
 
@@ -652,12 +659,12 @@ main() {
     local _dir
     for _dir in "${_chroot}" "${_srcroot}"; do
         if [ ! -d "${_dir}" ]; then
-            echo "${_dir} is not a directory" >&2
+            warn "${_dir} is not a directory"
             exit 1
         # TODO(lxnay): uncomment this before release
         #elif [ -n "$(ls -1 "${_dir}")" ] && \
         #    [ "${_dir}" = "${_chroot}" ]; then
-        #    echo "${_dir} is not empty" >&2
+        #    warn "${_dir} is not empty"
         #    return 1
         fi
     done
@@ -718,6 +725,13 @@ main() {
 
 }
 
-main "${@}" || exit ${?}
+main "${@}"
+main_ret=$?
+separator
+if [[ ${main_ret} -eq 0 ]]; then
+    echo "Commands completed successfully."
+else
+    warn "Failure! Exit status is ${main_ret}."
+fi
 
 # vim: expandtab
